<?xml version="1.0" encoding="ISO-8859-1"?>

<!-- ***************
     This xsl stylesheet will run with the xml produced by DVDprofiler to produce html.
     BUT change the first line of the output from DVDprofiler to match
     the first line of this file (i.e. encoding="ISO-8859-1")
     
     Then add the line
     
     <?xml-stylesheet type="text/xsl" href="dsmith_collection.xsl"?>
     
     As the secound line of the XML file, replace the href with the correct
     path to where you've stored this file if it's not in the same directory.
     
     For the dvd cover images to work you will also need to correct the path
     info further down this file - see later comment.
     
     Programmed by David Smith (Kinematics - dsmith@mad.scientist.com) 4 Mar 2003
     
     *************** -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:output method="html"
  encoding="ISO-8859-1"
  doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
  doctype-system="http://www.w3.org/TR/html401/loose.dtd"/>

<!-- ***************
     To make use of the DVD cover images, change the first following variable to the path
     of the local installation of DVD Profiler
     
     Note that the thumbnails won't exist unless you've already run a report inside
     DVD Profiler that makes use of them, such as the IVS Classic DVD Listing.
     
     *************** -->

<xsl:variable name="dvdprofilerpath">C:/Program Files/DVD Profiler</xsl:variable>
<xsl:variable name="dvdprofilerimagespath"><xsl:value-of select="$dvdprofilerpath"/>/images</xsl:variable>
<xsl:variable name="dvdprofilerthumbnailspath"><xsl:value-of select="$dvdprofilerimagespath"/>/thumbnails</xsl:variable>

<!-- ***************
     The following is the "Image Not Available" graphic.  Not sure how to determine when
     the image isn't available, so isn't used for now.
     *************** -->
<xsl:variable name="noimagefile"><xsl:value-of select="$dvdprofilerpath"/>/media/sysimagena.jpg</xsl:variable>


<!-- ***************
     The code generated with this XSLT transform also includes classes useable
     with stylesheet code.  You may create that stylesheet to fit your needs.
     *************** -->

<xsl:template match="Collection">
<html>
  <head>
    <title>DVD Collection</title>
    <link rel="stylesheet" title="Default" type="text/css" media="screen" href="collection.css"/>
  </head>
  <body>
    <h1>DVD Collection</h1>
    <xsl:apply-templates select="DVD"><xsl:sort select="SortTitle"/></xsl:apply-templates>
  </body>
</html>
</xsl:template>

<xsl:template match="DVD">
  <xsl:variable name="imagefile">
    <xsl:text>file://</xsl:text>
    <xsl:value-of select="$dvdprofilerthumbnailspath"/>
    <xsl:text>/</xsl:text>
    <xsl:value-of select="ID"/>
    <xsl:text>f.jpg</xsl:text>
  </xsl:variable>
  <div class="dvdWrapper">
    <table class="dvdEntry" border="0" cellpadding="0">
      <tr>
        <td class="imageCell">
          <xsl:element name="img">
            <xsl:attribute name="src">
              <xsl:value-of select="$imagefile"/>
            </xsl:attribute>
            <xsl:attribute name="width">
              <xsl:value-of select="120"/>
            </xsl:attribute>
            <xsl:attribute name="height">
              <xsl:value-of select="175"/>
            </xsl:attribute>
            <xsl:attribute name="alt">
              <xsl:text>Cover image for </xsl:text>
              <xsl:value-of select="Title"/>
            </xsl:attribute>
          </xsl:element>
        </td>
        <td class="dataCell">
          <table class="dvdData" border="0">
            <tr>
              <td class="dvdTitle" colspan="5"><xsl:value-of select="Title"/></td>
            </tr>
            <tr>
              <td class="dvdDirectors" colspan="5"><xsl:apply-templates select="Directors"/></td>
            </tr>
            <tr>
              <td class="dvdGenres" colspan="5"><xsl:apply-templates select="Genres"/></td>
            </tr>
            <tr>
              <td class="dvdSubtitles" colspan="5"><xsl:apply-templates select="Subtitles"/></td>
            </tr>
            <tr class="splitterRow">
              <td class="splitter" colspan="2"></td>
              <td></td>
              <td class="splitter" colspan="2"></td>
            </tr>
            <tr>
              <td class="dvdYear"><xsl:text>Produced</xsl:text></td>
              <td class="dvdYear"><xsl:value-of select="ProductionYear"/></td>
              <td></td>
              <td class="dvdRating"><xsl:text>Rating</xsl:text></td>
              <td class="dvdRating"><xsl:value-of select="Rating"/></td>
            </tr>
            <tr>
              <td class="dvdReleased"><xsl:text>Released</xsl:text></td>
              <td class="dvdReleased">
                <xsl:choose>
                  <xsl:when test="Released='1899-12-30'">
                    <xsl:text>Unknown</xsl:text>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="Released"/>
                  </xsl:otherwise>
                </xsl:choose>
              </td>
              <td></td>
              <td class="dvdRunningTime"><xsl:text>Running Time</xsl:text></td>
              <td class="dvdRunningTime"><xsl:value-of select="RunningTime"/></td>
            </tr>
            <tr>
              <td class="dvdPurchased"><xsl:text>Purchased</xsl:text></td>
              <td class="dvdPurchased">
                <xsl:choose>
                  <xsl:when test="CollectionType='WishList'">
                    <xsl:text>Wishlist</xsl:text>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="PurchaseInfo/PurchaseDate"/>
                  </xsl:otherwise>
                </xsl:choose>
              </td>
              <td></td>
              <td class="dvdCollection"><xsl:text>Collection #</xsl:text></td>
              <td class="dvdCollection"><xsl:value-of select="CollectionNumber"/></td>
            </tr>
            <tr class="splitterRow">
              <td class="splitter" colspan="2"></td>
              <td></td>
              <td class="splitter" colspan="2"></td>
            </tr>
            <tr>
              <td class="dvdLanguageTitle"><xsl:text>Language</xsl:text></td>
              <td class="dvdFormatTitle"><xsl:text>Format</xsl:text></td>
            </tr>
            <xsl:apply-templates select="Audio"/>
          </table>
        </td>
      </tr>
    </table>
  </div>
</xsl:template>


<xsl:template match="Directors">
  <xsl:if test="count(Director)&gt;0">
    <xsl:text>Director</xsl:text>
    <xsl:if test="count(Director)&gt;1">
      <xsl:text>s</xsl:text>
    </xsl:if>
    <xsl:text>: </xsl:text>
    <xsl:for-each select="Director">
      <xsl:value-of select="FirstName"/>
      <xsl:text> </xsl:text>
      <xsl:value-of select="LastName"/>
      <xsl:if test="not (position()=last())">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:for-each>
  </xsl:if>
</xsl:template>

<xsl:template match="Genres">
  <xsl:if test="count(Genre)&gt;0">
    <xsl:text>Genre</xsl:text>
    <xsl:if test="count(Genre)&gt;1">
      <xsl:text>s</xsl:text>
    </xsl:if>
    <xsl:text>: </xsl:text>
    <xsl:for-each select="Genre">
      <xsl:value-of select="."/>
      <xsl:if test="not (position()=last())">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:for-each>
  </xsl:if>
</xsl:template>

<xsl:template match="Subtitles">
  <xsl:if test="count(Subtitle)&gt;0">
    <xsl:text>Subtitles: </xsl:text>
    <xsl:for-each select="Subtitle">
      <xsl:value-of select="."/>
      <xsl:if test="not (position()=last())">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:for-each>
  </xsl:if>
</xsl:template>

<xsl:template match="Audio">
  <xsl:for-each select="AudioFormat">
    <tr>
      <td class="dvdAudioLanguage"><xsl:value-of select="AudioLanguage"/></td>
      <td class="dvdAudioFormat">
        <xsl:value-of select="substring-before(AudioCompression,' ')"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="AudioChannels"/>
      </td>
    </tr>
  </xsl:for-each>
</xsl:template>


<!-- ***************
     Features are not displayed by this XSLT file.  Left this code in for reference.
     *************** -->

<xsl:template match="Features">
  <xsl:for-each select="child::*">
    <xsl:if test=".='True'">
      <xsl:apply-templates select="current()" mode="featurenames"/>
    </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template match="*" mode="featurenames">
  <xsl:choose>
    <xsl:when test="name()='FeatureSceneAccess'">
      <xsl:text>Scene Access</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureCommentary'">
      <xsl:text>Commentary</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureTrailer'">
      <xsl:text>Trailers</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureDeletedScenes'">
      <xsl:text>Deleted Scenes</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureMakingOf'">
      <xsl:text>Making Of</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureProductionNotes'">
      <xsl:text>Production Notes</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureGame'">
      <xsl:text>Game</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureDVDROMContent'">
      <xsl:text>DVD-ROM Content</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureMultiAngle'">
      <xsl:text>MultiAngle</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureMusicVideos'">
      <xsl:text>Music Videos</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureClosedCaptioned'">
      <xsl:text>Closed Captioned</xsl:text><br/>
    </xsl:when>
    <xsl:when test="name()='FeatureTHXCertified'">
      <xsl:text>THX Certified</xsl:text><br/>
    </xsl:when>
  </xsl:choose>
</xsl:template>


</xsl:stylesheet>

